@@ -1,7 +1,8 @@
 # Copyright: Ankitects Pty Ltd and contributors
 # License: GNU AGPL, version 3 or later; http://www.gnu.org/licenses/agpl.html
 
-from typing import Any, Callable, Sequence, Type, Union
+from collections.abc import Callable, Sequence
+from typing import Any, Type, Union
 
 import anki
 from anki.collection import Collection
