@@ -3,13 +3,13 @@
 # pytype: disable=attribute-error
 # type: ignore
 # pylint: disable=C
+from __future__ import annotations
 
 import re
 import sys
 import time
 import unicodedata
 from string import capwords
-from typing import Optional, Union
 from xml.dom import minidom
 from xml.dom.minidom import Element, Text
 
@@ -329,7 +329,7 @@ class SupermemoXmlImporter(NoteImporter):
         self.logger("Load done.")
 
     # PARSE
-    def parse(self, node: Optional[Union[Text, Element]] = None) -> None:
+    def parse(self, node: Text | Element | None = None) -> None:
         "Parse method - parses document elements"
 
         if node is None and self.xmldoc is not None:
