@@ -8,7 +8,8 @@ from __future__ import annotations
 import json
 import random
 import time
-from typing import Sequence
+from collections.abc import Sequence
+from typing import Any
 
 import anki.cards
 import anki.collection
@@ -721,7 +722,7 @@ select count(), avg(ivl), max(ivl) from cards where did in %s and queue = {QUEUE
             tot = bad + good
             try:
                 pct = good / float(tot) * 100
-            except:
+            except Exception:
                 pct = 0
             i.append(
                 "Correct: <b>%(pct)0.2f%%</b><br>(%(good)d of %(tot)d)"
@@ -973,7 +974,7 @@ from cards where did in %s"""
         else:
             conf["legend"] = {"container": "#%sLegend" % id, "noColumns": 10}
         conf["series"] = dict(stack=True)
-        if not "yaxis" in conf:
+        if "yaxis" not in conf:
             conf["yaxis"] = {}
         conf["yaxis"]["labelWidth"] = 40
         if "xaxis" not in conf:
@@ -1089,6 +1090,7 @@ $(function () {
         lim = self._revlogLimit()
         if lim:
             lim = " where " + lim
+        t = 0
         if by == "review":
             t = self.col.db.scalar("select id from revlog %s order by id limit 1" % lim)
         elif by == "add":
