@@ -3,6 +3,7 @@
 
 from __future__ import annotations
 
+import atexit
 import logging
 import sys
 from collections.abc import Callable
@@ -518,6 +519,7 @@ def setupGL(pm: aqt.profiles.ProfileManager) -> None:
             print(f"Qt {category}: {msg} {context}")
 
     qInstallMessageHandler(msgHandler)
+    atexit.register(qInstallMessageHandler, None)
 
     if driver == VideoDriver.OpenGL:
         # Leaving QT_OPENGL unset appears to sometimes produce different results
@@ -559,7 +561,7 @@ def write_profile_results() -> None:
 
 
 def run() -> None:
-    print("Preparing to run...")
+    print(f"Starting Anki {_version}...")
     try:
         _run()
     except Exception as e:
