@@ -157,7 +157,8 @@ class CardLayout(QDialog):
         )
 
     def _fieldsOnTemplate(self, fmt: str) -> str:
-        matches = re.findall("{{[^#/}]+?}}", fmt)
+        fmt_without_comments = re.sub("<!--.*?-->", "", fmt)
+        matches = re.findall("{{[^#/}]+?}}", fmt_without_comments)
         chars_allowed = 30
         field_names: list[str] = []
         for m in matches:
@@ -753,6 +754,31 @@ class CardLayout(QDialog):
         dst["afmt"] = "{{FrontSide}}\n\n<hr id=answer>\n\n%s" % src["qfmt"]
         dst["qfmt"] = m.group(2).strip()
 
+    def onCopyMarkdown(self) -> None:
+        template = self.current_template()
+
+        def sanitizeMarkdown(md):
+            return md.replace("```", "\\`\\`\\`")
+
+        markdown = (
+            f"## Front Template\n"
+            "```html\n"
+            f"{sanitizeMarkdown(template['qfmt'])}\n"
+            "```\n"
+            "## Back Template\n"
+            "```html\n"
+            f"{sanitizeMarkdown(template['afmt'])}\n"
+            "```\n"
+            "## Styling\n"
+            "```css\n"
+            f"{sanitizeMarkdown(self.model['css'])}\n"
+            "```\n"
+        )
+        clipboard = QApplication.clipboard()
+        assert clipboard is not None
+        clipboard.setText(markdown)
+        tooltip(tr.about_copied_to_clipboard())
+
     def onMore(self) -> None:
         m = QMenu(self)
 
@@ -793,6 +819,10 @@ class CardLayout(QDialog):
             assert a is not None
             qconnect(a.triggered, self.onTargetDeck)
 
+            a = m.addAction(tr.card_templates_copy_info())
+            assert a is not None
+            qconnect(a.triggered, self.onCopyMarkdown)
+
         a = m.addAction(tr.card_templates_browser_appearance())
         assert a is not None
         qconnect(a.triggered, self.onBrowserDisplay)
