@@ -18,7 +18,7 @@ import warnings
 from collections.abc import Callable
 from enum import Enum
 from random import randrange
-from typing import Any, Match, cast
+from typing import Any, Iterable, Match, cast
 
 import bs4
 import requests
@@ -139,9 +139,13 @@ class Editor:
         # Similar to currentField, but not set to None on a blur. May be
         # outside the bounds of the current notetype.
         self.last_field_index: int | None = None
+        # used when creating a copy of an existing note
+        self.orig_note_id: NoteId | None = None
         # current card, for card layout
         self.card: Card | None = None
         self.state: EditorState = EditorState.INITIAL
+        # used for the io mask editor's context menu
+        self.last_io_image_path: str | None = None
         self._init_links()
         self.setupOuter()
         self.add_webview()
@@ -524,7 +528,10 @@ require("anki/ui").loaded.then(() => require("anki/NoteEditor").instances[0].too
     ######################################################################
 
     def set_note(
-        self, note: Note | None, hide: bool = True, focusTo: int | None = None
+        self,
+        note: Note | None,
+        hide: bool = True,
+        focusTo: int | None = None,
     ) -> None:
         "Make NOTE the current note."
         self.note = note
@@ -596,12 +603,18 @@ require("anki/ui").loaded.then(() => require("anki/NoteEditor").instances[0].too
             sticky = [field["sticky"] for field in self.note_type()["flds"]]
             js += " setSticky(%s);" % json.dumps(sticky)
 
-        if (
-            self.editorMode != EditorMode.ADD_CARDS
-            and self.current_notetype_is_image_occlusion()
-        ):
-            io_options = self._create_edit_io_options(note_id=self.note.id)
-            js += " setupMaskEditor(%s);" % json.dumps(io_options)
+        if self.current_notetype_is_image_occlusion():
+            io_field_indices = self.mw.backend.get_image_occlusion_fields(self.note.mid)
+            image_field = self.note.fields[io_field_indices.image]
+            self.last_io_image_path = self.extract_img_path_from_html(image_field)
+
+            if self.editorMode is not EditorMode.ADD_CARDS:
+                io_options = self._create_edit_io_options(note_id=self.note.id)
+                js += " setupMaskEditor(%s);" % json.dumps(io_options)
+            elif orig_note_id := self.orig_note_id:
+                self.orig_note_id = None
+                io_options = self._create_clone_io_options(orig_note_id)
+                js += " setupMaskEditor(%s);" % json.dumps(io_options)
 
         js = gui_hooks.editor_will_load_note(js, self.note, self)
         self.web.evalWithCallback(
@@ -700,6 +713,7 @@ require("anki/ui").loaded.then(() => require("anki/NoteEditor").instances[0].too
         return True
 
     def cleanup(self) -> None:
+        av_player.stop_and_clear_queue_if_caller(self.editorMode)
         self.set_note(None)
         # prevent any remaining evalWithCallback() events from firing after C++ object deleted
         if self.web:
@@ -836,8 +850,12 @@ require("anki/ui").loaded.then(() => require("anki/NoteEditor").instances[0].too
     # Media downloads
     ######################################################################
 
-    def urlToLink(self, url: str) -> str:
-        fname = self.urlToFile(url)
+    def urlToLink(self, url: str, allowed_suffixes: Iterable[str] = ()) -> str:
+        fname = (
+            self.urlToFile(url, allowed_suffixes)
+            if allowed_suffixes
+            else self.urlToFile(url)
+        )
         if not fname:
             return '<a href="{}">{}</a>'.format(
                 url, html.escape(urllib.parse.unquote(url))
@@ -850,12 +868,14 @@ require("anki/ui").loaded.then(() => require("anki/NoteEditor").instances[0].too
             name = urllib.parse.quote(fname.encode("utf8"))
             return f'<img src="{name}">'
         else:
-            av_player.play_file(fname)
+            av_player.play_file_with_caller(fname, self.editorMode)
             return f"[sound:{html.escape(fname, quote=False)}]"
 
-    def urlToFile(self, url: str) -> str | None:
+    def urlToFile(
+        self, url: str, allowed_suffixes: Iterable[str] = pics + audio
+    ) -> str | None:
         l = url.lower()
-        for suffix in pics + audio:
+        for suffix in allowed_suffixes:
             if l.endswith(f".{suffix}"):
                 return self._retrieveURL(url)
         # not a supported type
@@ -1086,6 +1106,14 @@ require("anki/ui").loaded.then(() => require("anki/NoteEditor").instances[0].too
 
         self.parentWindow.activateWindow()
 
+    def extract_img_path_from_html(self, html: str) -> str | None:
+        assert self.note is not None
+        # with allowed_suffixes=pics, all non-pics will be rendered as <a>s and won't be included here
+        if not (images := self.mw.col.media.files_in_str(self.note.mid, html)):
+            return None
+        image_path = urllib.parse.unquote(images[0])
+        return os.path.join(self.mw.col.media.dir(), image_path)
+
     def select_image_from_clipboard_and_occlude(self) -> None:
         """Set up the mask editor for the image in the clipboard."""
 
@@ -1093,12 +1121,16 @@ require("anki/ui").loaded.then(() => require("anki/NoteEditor").instances[0].too
         assert clipboard is not None
         mime = clipboard.mimeData()
         assert mime is not None
-        if not mime.hasImage():
+        # try checking for urls first, fallback to image data
+        if (
+            (html := self.web._processUrls(mime, allowed_suffixes=pics))
+            and (path := self.extract_img_path_from_html(html))
+        ) or (mime.hasImage() and (path := self._read_pasted_image(mime))):
+            self.setup_mask_editor(path)
+            self.parentWindow.activateWindow()
+        else:
             showWarning(tr.editing_no_image_found_on_clipboard())
             return
-        path = self._read_pasted_image(mime)
-        self.setup_mask_editor(path)
-        self.parentWindow.activateWindow()
 
     def setup_mask_editor_for_new_note(
         self,
@@ -1114,6 +1146,7 @@ require("anki/ui").loaded.then(() => require("anki/NoteEditor").instances[0].too
               found image occlusion notetype in the user's collection.
         """
         image_field_html = self._addMedia(image_path)
+        self.last_io_image_path = self.extract_img_path_from_html(image_field_html)
         io_options = self._create_add_io_options(
             image_path=image_path,
             image_field_html=image_field_html,
@@ -1134,6 +1167,7 @@ require("anki/ui").loaded.then(() => require("anki/NoteEditor").instances[0].too
         io_options = self._create_edit_io_options(note_id)
         if image_path:
             image_field_html = self._addMedia(image_path)
+            self.last_io_image_path = self.extract_img_path_from_html(image_field_html)
             self.web.eval(f"resetIOImage({json.dumps(image_path)})")
             self.web.eval(f"setImageField({json.dumps(image_field_html)})")
         self._setup_mask_editor(io_options)
@@ -1160,6 +1194,12 @@ require("anki/ui").loaded.then(() => require("anki/NoteEditor").instances[0].too
             "html": image_field_html,
         }
 
+    @staticmethod
+    def _create_clone_io_options(orig_note_id: NoteId) -> dict:
+        return {
+            "mode": {"kind": "add", "clonedNoteId": orig_note_id},
+        }
+
     @staticmethod
     def _create_edit_io_options(note_id: NoteId) -> dict:
         return {"mode": {"kind": "edit", "noteId": note_id}}
@@ -1438,24 +1478,28 @@ class EditorWebView(AnkiWebView):
         self._store_field_content_on_next_clipboard_change = True
         self._internal_field_text_for_paste = None
 
-    def _on_clipboard_change(self) -> None:
-        self._last_known_clipboard_mime = self._clipboard().mimeData()
+    def _on_clipboard_change(
+        self, mode: QClipboard.Mode = QClipboard.Mode.Clipboard
+    ) -> None:
+        self._last_known_clipboard_mime = self._clipboard().mimeData(mode)
         if self._store_field_content_on_next_clipboard_change:
             # if the flag was set, save the field data
-            self._internal_field_text_for_paste = self._get_clipboard_html_for_field()
+            self._internal_field_text_for_paste = self._get_clipboard_html_for_field(
+                mode
+            )
             self._store_field_content_on_next_clipboard_change = False
-        elif (
-            self._internal_field_text_for_paste != self._get_clipboard_html_for_field()
+        elif self._internal_field_text_for_paste != self._get_clipboard_html_for_field(
+            mode
         ):
             # if we've previously saved the field, blank it out if the clipboard state has changed
             self._internal_field_text_for_paste = None
 
-    def _get_clipboard_html_for_field(self):
+    def _get_clipboard_html_for_field(self, mode: QClipboard.Mode) -> str | None:
         clip = self._clipboard()
-        mime = clip.mimeData()
+        mime = clip.mimeData(mode)
         assert mime is not None
         if not mime.hasHtml():
-            return
+            return None
         return mime.html()
 
     def onCut(self) -> None:
@@ -1468,6 +1512,8 @@ class EditorWebView(AnkiWebView):
         self.triggerPageAction(QWebEnginePage.WebAction.CopyImageToClipboard)
 
     def _opened_context_menu_on_image(self) -> bool:
+        if not hasattr(self, "lastContextMenuRequest"):
+            return False
         context_menu_request = self.lastContextMenuRequest()
         assert context_menu_request is not None
         return (
@@ -1486,8 +1532,8 @@ class EditorWebView(AnkiWebView):
     def _onPaste(self, mode: QClipboard.Mode) -> None:
         # Since _on_clipboard_change doesn't always trigger properly on macOS, we do a double check if any changes were made before pasting
         clipboard = self._clipboard()
-        if self._last_known_clipboard_mime != clipboard.mimeData():
-            self._on_clipboard_change()
+        if self._last_known_clipboard_mime != clipboard.mimeData(mode):
+            self._on_clipboard_change(mode)
         extended = self._wantsExtendedPaste()
         if html := self._internal_field_text_for_paste:
             print("reuse internal")
@@ -1515,7 +1561,17 @@ class EditorWebView(AnkiWebView):
         extended = self._wantsExtendedPaste()
         mime = evt.mimeData()
         assert mime is not None
-        cursor_pos = self.mapFromGlobal(QCursor.pos())
+
+        if (
+            self.editor.state is EditorState.IO_PICKER
+            and (html := self._processUrls(mime, allowed_suffixes=pics))
+            and (path := self.editor.extract_img_path_from_html(html))
+        ):
+            self.editor.setup_mask_editor(path)
+            return
+
+        evt_pos = evt.position()
+        cursor_pos = QPoint(int(evt_pos.x()), int(evt_pos.y()))
 
         if evt.source() and mime.hasHtml():
             # don't filter html from other fields
@@ -1549,15 +1605,19 @@ class EditorWebView(AnkiWebView):
             html_content = mime.html()[11:] if internal else mime.html()
             return html_content, internal
 
+        # given _processUrls' extra allowed_suffixes kwarg, placate the typechecker
+        def process_url(mime: QMimeData, extended: bool = False) -> str | None:
+            return self._processUrls(mime, extended)
+
         # favour url if it's a local link
         if (
             mime.hasUrls()
             and (urls := mime.urls())
             and urls[0].toString().startswith("file://")
         ):
-            types = (self._processUrls, self._processImage, self._processText)
+            types = (process_url, self._processImage, self._processText)
         else:
-            types = (self._processImage, self._processUrls, self._processText)
+            types = (self._processImage, process_url, self._processText)
 
         for fn in types:
             html = fn(mime, extended)
@@ -1565,7 +1625,12 @@ class EditorWebView(AnkiWebView):
                 return html, True
         return "", False
 
-    def _processUrls(self, mime: QMimeData, extended: bool = False) -> str | None:
+    def _processUrls(
+        self,
+        mime: QMimeData,
+        extended: bool = False,
+        allowed_suffixes: Iterable[str] = (),
+    ) -> str | None:
         if not mime.hasUrls():
             return None
 
@@ -1575,7 +1640,7 @@ class EditorWebView(AnkiWebView):
             # chrome likes to give us the URL twice with a \n
             if lines := url.splitlines():
                 url = lines[0]
-                buf += self.editor.urlToLink(url)
+                buf += self.editor.urlToLink(url, allowed_suffixes=allowed_suffixes)
 
         return buf
 
@@ -1628,7 +1693,11 @@ class EditorWebView(AnkiWebView):
         a = m.addAction(tr.editing_paste())
         assert a is not None
         qconnect(a.triggered, self.onPaste)
-        if self._opened_context_menu_on_image():
+        if self.editor.state is EditorState.IO_MASKS and (
+            path := self.editor.last_io_image_path
+        ):
+            self._add_image_menu_with_path(m, path)
+        elif self._opened_context_menu_on_image():
             self._add_image_menu(m)
         gui_hooks.editor_will_show_context_menu(self, m)
         m.popup(QCursor.pos())
@@ -1653,6 +1722,9 @@ class EditorWebView(AnkiWebView):
         url = context_menu_request.mediaUrl()
         file_name = url.fileName()
         path = os.path.join(self.editor.mw.col.media.dir(), file_name)
+        self._add_image_menu_with_path(menu, path)
+
+    def _add_image_menu_with_path(self, menu: QMenu, path: str) -> None:
         a = menu.addAction(tr.editing_open_image())
         assert a is not None
         qconnect(a.triggered, lambda: openFolder(path))
