@@ -147,17 +147,27 @@ class MainWebView(AnkiWebView):
             return
 
     # Main webview specific event handling
-    def eventFilter(self, obj, evt):
+    def eventFilter(self, obj: QObject | None, evt: QEvent | None) -> bool:
         if handled := super().eventFilter(obj, evt):
             return handled
 
         if evt.type() == QEvent.Type.Leave:
+            handled_leave = False
+
+            # Show menubar when mouse moves outside main webview in fullscreen
+            if self.mw.fullscreen:
+                self.mw.show_menubar()
+                handled_leave = True
+
             # Show toolbar when mouse moves outside main webview
             # and automatically hide it with delay after mouse has entered again
+            # The toolbar's hide timer will also trigger menubar hiding when in fullscreen mode
             if self.mw.pm.hide_top_bar() or self.mw.pm.hide_bottom_bar():
                 self.mw.toolbarWeb.show()
                 self.mw.bottomWeb.show()
-                return True
+                handled_leave = True
+
+            return handled_leave
 
         if evt.type() == QEvent.Type.Enter:
             self.mw.toolbarWeb.hide_timer.start()
@@ -790,12 +800,20 @@ class AnkiQt(QMainWindow):
     def _reviewState(self, oldState: MainWindowState) -> None:
         self.reviewer.show()
 
+        fullscreen_was_checked = False
+
         if self.pm.hide_top_bar():
             self.toolbarWeb.hide_timer.setInterval(500)
             self.toolbarWeb.hide_timer.start()
+
+            # check the `hide_if_allowed` method in `qt/aqt/toolbar.py`
+            fullscreen_was_checked = True
         else:
             self.toolbarWeb.flatten()
 
+        if not fullscreen_was_checked and self.fullscreen:
+            self.hide_menubar()
+
         if self.pm.hide_bottom_bar():
             self.bottomWeb.hide_timer.setInterval(500)
             self.bottomWeb.hide_timer.start()
