@@ -140,6 +140,8 @@ class AVPlayer:
     # when a new batch of audio is played, should the currently playing
     # audio be stopped?
     interrupt_current_audio = True
+    # caller key for the current playback (optional)
+    current_caller = None
 
     def __init__(self) -> None:
         self._enqueued: list[AVTag] = []
@@ -163,6 +165,10 @@ class AVPlayer:
         self._enqueued = []
         self._stop_if_playing()
 
+    def stop_and_clear_queue_if_caller(self, caller) -> None:
+        if caller == self.current_caller:
+            self.stop_and_clear_queue()
+
     def clear_queue_and_maybe_interrupt(self) -> None:
         self._enqueued = []
         if self.interrupt_current_audio:
@@ -171,6 +177,10 @@ class AVPlayer:
     def play_file(self, filename: str) -> None:
         self.play_tags([SoundOrVideoTag(filename=filename)])
 
+    def play_file_with_caller(self, filename: str, caller) -> None:
+        self.current_caller = caller
+        self.play_file(filename)
+
     def insert_file(self, filename: str) -> None:
         self._enqueued.insert(0, SoundOrVideoTag(filename=filename))
         self._play_next_if_idle()
@@ -187,6 +197,7 @@ class AVPlayer:
         self.stop_and_clear_queue()
         for player in self.players:
             player.shutdown()
+        self.players.clear()
 
     def _stop_if_playing(self) -> None:
         if self.current_player:
@@ -198,6 +209,7 @@ class AVPlayer:
         return self._enqueued.pop(0)
 
     def _on_play_finished(self) -> None:
+        self.current_caller = None
         gui_hooks.av_player_did_end_playing(self.current_player)
         self.current_player = None
         self._play_next_if_idle()
@@ -245,7 +257,8 @@ av_player = AVPlayer()
 def _packagedCmd(cmd: list[str]) -> tuple[Any, dict[str, str]]:
     cmd = cmd[:]
     env = os.environ.copy()
-    if "LD_LIBRARY_PATH" in env:
+    # keep LD_LIBRARY_PATH when in snap environment
+    if "LD_LIBRARY_PATH" in env and "SNAP" not in env:
         del env["LD_LIBRARY_PATH"]
 
     if is_win:
@@ -415,6 +428,12 @@ class MpvManager(MPV, SoundOrVideoPlayer):
         if self._on_done:
             self._on_done()
 
+        m = re.search(r"(\d+)\.(\d+)\.(\d+)", self.get_property("mpv-version"))
+        if m:
+            self.mpv_version = (int(m[1]), int(m[2]), int(m[3]))
+        else:
+            self.mpv_version = None
+
         try:
             self.command("keybind", "q", "stop")
             self.command("keybind", "Q", "stop")
@@ -430,7 +449,10 @@ class MpvManager(MPV, SoundOrVideoPlayer):
         filename = hooks.media_file_filter(tag.filename)
         path = os.path.join(self.media_folder, filename)
 
-        self.command("loadfile", path, "replace")
+        if self.mpv_version is None or self.mpv_version >= (0, 38, 0):
+            self.command("loadfile", path, "replace", -1, "pause=no")
+        else:
+            self.command("loadfile", path, "replace", "pause=no")
         gui_hooks.av_player_did_begin_playing(self, tag)
 
     def stop(self) -> None:
