@@ -611,6 +611,7 @@ html {{ {font} }}
         # print(html)
         import aqt.browser.previewer
         import aqt.clayout
+        import aqt.deckoptions
         import aqt.editor
         import aqt.reviewer
         from aqt.mediasrv import PageContext
@@ -623,6 +624,8 @@ html {{ {font} }}
             page_context = PageContext.PREVIEWER
         elif isinstance(context, aqt.clayout.CardLayout):
             page_context = PageContext.CARD_LAYOUT
+        elif isinstance(context, aqt.deckoptions.DeckOptionsDialog):
+            page_context = PageContext.DECK_OPTIONS
         else:
             page_context = PageContext.UNKNOWN
         self.setHtml(html, page_context)
@@ -656,17 +659,17 @@ html {{ {font} }}
         page = self.page()
         assert page is not None
 
-        if cb:
-
-            def handler(val: Any) -> None:
-                if self._shouldIgnoreWebEvent():
-                    print("ignored late js callback", cb)
-                    return
+        def handler(val: Any) -> None:
+            if self._shouldIgnoreWebEvent():
+                print("ignored late js callback", cb)
+                return
+            if cb:
                 cb(val)
 
-            page.runJavaScript(js, handler)
-        else:
-            page.runJavaScript(js)
+            # Without the following, stale frames showing previous or corrupt content get occasionally displayed. (see #3668 for more details)
+            self.update()
+
+        page.runJavaScript(js, handler)
 
     def _queueAction(self, name: str, *args: Any) -> None:
         self._pendingActions.append((name, args))
@@ -838,6 +841,14 @@ html {{ {font} }}
     def on_theme_did_change(self) -> None:
         # avoid flashes if page reloaded
         self._page.setBackgroundColor(theme_manager.qcolor(colors.CANVAS))
+        if hasattr(QWebEngineSettings.WebAttribute, "ForceDarkMode"):
+            force_dark_mode = getattr(QWebEngineSettings.WebAttribute, "ForceDarkMode")
+            page_settings = self._page.settings()
+            if page_settings is not None:
+                page_settings.setAttribute(
+                    force_dark_mode,
+                    theme_manager.get_night_mode(),
+                )
         # update night-mode class, and legacy nightMode/night-mode body classes
         self.eval(
             f"""
